---
lang: en-us
---

# markdown-latex-pandoc

A combination of Markdown, Latex with Biblatex, Pandoc and a Makefile to put everything easily in a PDF.

**TLDR: Put your content in `content.md`, your references in `refs.bib`, and run `make pdf`**

## Setup

There is a Makefile in the root of this folder. To execute this you need to have make installed, and you need to be on a UNIX system.

### PDF

`make pdf`

There is a preconfigured workflow for a PDF. Just run `make pdf` to enable all supported features. The PDF will be outputted to `data/content.pdf`.

### PDF no bibliography

`make pdf-no-bib`

Same as PDF, just without supporting bibliography.

### Pandoc

`make pandoc`

This will just create a .tex file.

### Pandoc without bibliography

`make pandoc-no-bib`

Same as Pandoc, just without supporting bibliography.

### Tex

`make tex`

This will run Latex on the .tex file.

### Clear

`make clear`

Remove all build files in the build folder.

## Options

These are options for the YAML frontmatter. All are optional.

To use these you have to put it in the first lines of your .md file.

Example:

```yaml
---
title: "HELLO!"
author: "Fl1tzi"
---
```

### title

Specify the title of your document. This will also create a cover.

Example:

`title: "My awesome work"`

### author

Specify the author of the document. Only useful in combination with `title`.

Example:

`author: "Max Mustermann"`

### toc

Create a table-of-contents.

Example:

`toc: true`

### toc-title

Use a custom title in your TOC.

Example:

`toc-title: Gliederung`

### bibliography

With this option you specify where the bibliography file is located. The format has to be for Biblatex.

Example:

`bibliography: refs.bib`

### bibliography-title

Use a custom bibliography title.

Example:

`bibliography-title: Literaturverzeichnis`

### include-before

Allows you to apply custom settings in Latex before the actual document.

Example:

```yaml
include-before: |
  \linespread{1.2}
```

### include-after

Allows you to apply custom settings in Latex after the body. Useful for things that should come after the bibliography.

Example:

```yaml
include-after: |
  Thank you for reading this document!
```

